slepc-3.18.0 2022-10-01
Report Typos and Errors

# EPSEVSLSetDOSParameters

Defines the parameters used for computing the density of states (DOS) in the EVSL solver.

### Synopsis

    #include "slepceps.h"
    PetscErrorCode EPSEVSLSetDOSParameters(EPS eps,EPSEVSLDOSMethod dos,PetscInt nvec,PetscInt deg,PetscInt steps,PetscInt npoints)

Logically Collective on eps

### Input Parameters

| eps | - the eigensolver context
| dos | - DOS method, either KPM or Lanczos
| nvec | - number of sample vectors
| deg | - polynomial degree (KPM only)
| steps | - number of Lanczos steps (Lanczos only)
| npoints | - number of sample points (Lanczos only)

### Options Database Keys

| -eps_evsl_dos_method <dos> | - set the DOS method, either kpm or lanczos
| -eps_evsl_dos_nvec <n> | - set the number of sample vectors
| -eps_evsl_dos_degree <n> | - set the polynomial degree
| -eps_evsl_dos_steps <n> | - set the number of Lanczos steps
| -eps_evsl_dos_npoints <n> | - set the number of sample points

### Notes

The density of states (or spectral density) can be approximated with two methods, kernel polynomial method (KPM) or Lanczos. Some parameters for these methods can be set by the user with this function, with some of them being relevant for one of the methods only.

### See Also

EPSEVSLGetDOSParameters()

### Level

intermediate

### Location

src/eps/impls/external/evsl/evsl.c
Index of all EPS routines
Table of Contents for all manual pages
Index of all manual pages